@@ -1,5 +1,6 @@
 import gzip
 import base64
+from pyclbr import Class
 from .rest import *
 from .dassana_env import *
 from abc import ABCMeta, abstractmethod
@@ -20,7 +21,7 @@ class Pipe(metaclass=ABCMeta):
         pass
 
     def flush(self):
-        flush_res = forward_logs(self.json_logs, app_id=self.app_id)
+        flush_res = forward_logs(self.json_logs)
         self.json_logs = []
         return flush_res
         
@@ -343,17 +344,20 @@ class ConfigSnapshotPipe(Pipe):
     def __init__(self):
         super().__init__()
         self.bytes_so_far = 0
-        self.app_id = get_app_id()
 
     def push(self, content):
-        content["Cloud"] = "aws"
-        content["ResourceContainer"] = content["awsAccountID"]
-        content["Region"] = content["awsRegion"]
-        content["Service"] = content["resourceType"].split('::')[1]
-        content["ResourceName"] = content["tags"]["name"]
-        content["Config"] = content
-        self.json_logs.append(content)
-        self.bytes_so_far += len(dumps(content))
+        output = {}
+        output["Cloud"] = "aws"
+        output["ResourceContainer"] = content["awsAccountId"]
+        output["Region"] = content["awsRegion"]
+        output["Service"] = content["resourceType"].split('::')[1]
+        try:
+            output["ResourceName"] = content["resourceName"]
+        except:
+            pass
+        output["Config"] = content
+        self.json_logs.append(output)
+        self.bytes_so_far += len(dumps(output))
         if self.bytes_so_far >= (0.1 * 1048576):
             self.bytes_so_far = 0
             return True
@@ -363,28 +367,81 @@ class ConfigSnapshotPipe(Pipe):
 class ConfigChangePipe(Pipe):
     def __init__(self):
         super().__init__()
-        self.app_id = get_app_id()
 
     def push(self, content):
         items = content['Records']
         for item in items:
             item["body"] = loads(item["body"])
-            output = loads(item["body"]["Message"])
-            if output["messageType"] != "ConfigurationItemChangeNotification":
+            temp = loads(item["body"]["Message"])
+            if temp["messageType"] != "ConfigurationItemChangeNotification":
                 continue
+            output = {}
             output["Cloud"] = "aws"
-            output["ResourceContainer"] = output["configurationItem"]["awsAccountId"]
-            output["Region"] = output["configurationItem"]["awsRegion"]
-            output["Service"] = output["configurationItem"]["resourceType"].split("::")[1]
-            output["ResourceType"] = output["configurationItem"]["resourceType"]
-            output["ResourceID"] = output["configurationItem"]["resourceId"]
+            output["ResourceContainer"] = temp["configurationItem"]["awsAccountId"]
+            output["Region"] = temp["configurationItem"]["awsRegion"]
+            output["Service"] = temp["configurationItem"]["resourceType"].split("::")[1]
+            output["ResourceType"] = temp["configurationItem"]["resourceType"]
+            output["ResourceID"] = temp["configurationItem"]["resourceId"]
             try:
-                output["ResourceName"] = output["configurationItem"]["resourceName"]
+                output["ResourceName"] = temp["configurationItem"]["resourceName"]
             except:
                 pass
-            output["Config"] = output["configurationItem"]
+            output["Config"] = temp["configurationItem"]
             self.json_logs.append(output)
 
+class GithubAssetPipe(Pipe):
+    def __init__(self):
+        super().__init__()
+
+    def push(self, content):
+        for item in content:
+            output = {}
+            output["Cloud"] = "github"
+            output["ResourceContainer"] = item["owner"]["id"]
+            output["ResourceName"] = item["name"]
+            output["Region"] = "global"
+            output["Service"] = "git"
+            output["ResourceType"] = "repository"
+            output["ResourceID"] = item["id"]
+            output["Config"] = item
+            self.json_logs.append(output)
+
+class QualysPipe(Pipe):
+    def __init__(self):
+        super().__init__()
+
+    def push(self, content):
+        hosts = content["HOST_LIST_VM_DETECTION_OUTPUT"]["RESPONSE"]["HOST_LIST"]["HOST"]
+        if isinstance(hosts, list):
+            for host in hosts:
+                hostID = host["ID"]
+                detections = host["DETECTION_LIST"]["DETECTION"]
+                if isinstance(detections, list):
+                    for detection in detections:
+                        output = {}
+                        output["Config"] = detection
+                        output["ResourceID"] = hostID
+                        self.json_logs.append(output)
+                else:
+                    output = {}
+                    output["Config"] = detections
+                    output["ResourceID"] = hostID
+                    self.json_logs.append(output)
+        else:
+            hostID = hosts["ID"]
+            detections = hosts["DETECTION_LIST"]["DETECTION"]
+            if isinstance(detections, list):
+                for detection in detections:
+                    output = {}
+                    output["Config"] = detection
+                    output["ResourceID"] = hostID
+                    self.json_logs.append(output)
+            else:
+                output = {}
+                output["Config"] = detections
+                output["ResourceID"] = hostID
+                self.json_logs.append(output)
+
 def DataPipe():
     pipe_selector = {
         "aws_cloudtrail": CloudTrailPipe,
@@ -396,6 +453,8 @@ def DataPipe():
         "aws_network_firewall": NetworkFirewallPipe,
         "azure_test": AzureActivityPipe,
         "aws_eks": EKSPipe,
+        "github_assets": GithubAssetPipe,
+        "_qualys": QualysPipe
     }
     return pipe_selector[get_app_id()]()
 
